Learn R Programming

HEDA (version 0.1.5)

HPK_rt_dur: HPK_rt_dur

Description

Extract rate of change and duration related metrics

Usage

HPK_rt_dur(df)

Arguments

df

Dataframe to be processed

Value

Output dataframe includes time-series values of four metrics. Qpeak is the hydropeaking discharge, offQpeak isbase flow, pk_no is the daily number of rise and fall process, pkratio is the ratio of days with hydropeaking to thetotal number of days analyzed

Details

Extract rate of chane and duration related metrics: pk_rtn is the retention of peaking process. offpk_rtn is theretention of base flow. D_rampup/D_ramp is the duration of rise/fall process. RB_Indx_up/RB_Index_dw is theflashness of rise/fall process. Ramp_up/Ramp_dw is the rate of change of rise/fall process.Strange_up/Strange_dw is the standardized rise/fall amplitude

Examples

Run this code
# NOT RUN {
HpkRtDur <- HPK_rt_dur(hpk_flow_cg)

## to extract the time-series of one metric withouth missing value
pk_rtn <- HpkRtDur[na.omit(HpkRtDur$pk_rtn),c("location_id","datetime","pk_rtn")]
# }

Run the code above in your browser using DataLab